var inputFieldNames = ["file", "mapper", "currency", "startDate", "endDate", "timeframe"];

var initializeInput = function() {
	
	// Add the input HTML
	var html = `			
<div id="input_small" class="row" hidden>
	<div class="column">
		<h5 class="openclose">&#8618; Alter input</h5>
	</div>
</div>
<div id="input_large" class="row">
	<h4>Input</h4>
	<p>Please provide the following details to be able to analyze your bank transactions.</p>
	<form>
		<div class="six columns">
			<label for="input_file">Choose your CSV transaction data file: </label><input id="input_file" type="file"></input>
			<label for="input_mapper">Choose your mapper</label><select id="input_mapper"></select>
			<label for="input_currency">Choose your currency</label><select id="input_currency">
				<option value="&euro;">&euro;</option>
				<option value="&dollar;">&dollar;</option>
			</select>
		</div>
		<div class="six columns">
			<label for="input_startDate">Pick a start date </label><input id="input_startDate" type="text"></input>
			<label for="input_endDate">Pick an end date</label><input id="input_endDate" type="text"></input>
			<label for="input_timeframe">Choose your timeframe</label><select id="input_timeframe">
				<option value="day">Day</option>
				<option value="week">Week</option>
				<option value="month" selected>Month</option>
				<option value="year">Year</option>
			</select>
		</div>
	</form>
	<button id="input_button" class="button-primary danger">Click here to analyze your input!</button>
	<h5 class="openclose" style="width:100%; text-align:right;">&#8617;</h5>
</div>
	`;
	jQuery("#input").append(html);
	
	// Add mappers to the 'Choose your mapper' input field
	var mapperNames = Object.keys(mappers);
	var input_mapper = jQuery("#input_mapper");
	mapperNames.forEach(function (mapperName) {
		input_mapper.append("<option value='" + mapperName + "'>" + mapperName + "</option>");
	});
	
	// Set the dates of the 'Pick a start/end date' input fields
	var todayLastYear = new Date(); todayLastYear.setFullYear(todayLastYear.getFullYear() - 1);
	jQuery("#input_startDate").datepicker({ dateFormat: "yy-mm-dd" }).datepicker("setDate", todayLastYear);
	
	var today = new Date();
	jQuery("#input_endDate").datepicker({ dateFormat: "yy-mm-dd" }).datepicker("setDate", today);
};

var gatherInput = function() {
	var rawInput = {};
	inputFieldNames.forEach(function (inputFieldName) {
		var inputField = jQuery("#input_" + inputFieldName);
		var value = (inputFieldName == "file") ? inputField[0].files[0] : inputField.val();
		rawInput[inputFieldName] = value;
	});
	return {
		file: rawInput.file,
		mapper: mappers[rawInput.mapper],
		currency: rawInput.currency,
		startDate: new Date(rawInput.startDate),
		endDate: new Date(rawInput.endDate),
		timeframe: rawInput.timeframe,
	};
};

var isInputValid = function() {
	var input = gatherInput();
	
	// File
	if ((typeof input.file) !== "object" || input.file.constructor.name !== "File") {
		return false;
	}
	
	// Mapper
	if ((typeof input.mapper) !== "function") {
		return false;
	}
	
	// Start/End Date
	if (isNaN(input.startDate) || isNaN(input.endDate)) {
		return false;
	}
	
	return true;
};

var bindChangingInput = function(inputSendCallback) {	
	var inputFullDiv = jQuery("#input_large");
	var inputSmallDiv = jQuery("#input_small");
	
	var hideShow = function(showFull) {
		if (showFull) {
			inputFullDiv.show();
			inputSmallDiv.hide();
		} else {
			inputFullDiv.hide();
			inputSmallDiv.show();
		}
	};
	
	// Hide the "input_button" on start and send callback when clicked
	var input_button = jQuery("#input_button")
		.prop('disabled', true)
		.click(function() { 
			jQuery(this).prop('disabled', true);
			inputSendCallback(gatherInput());
			hideShow(false);
		});
	
	// Make on small click show the full input
	inputSmallDiv.click(function () {
		hideShow(true);
	});
	
	// Make on hide click hide the full input
	jQuery("#input_large .openclose, #input_large h4").click(function () {
		hideShow(false);
	});
	
	// Show the "input_button" on changing any of the fields
	inputFieldNames.forEach(function(inputFieldName) {
		jQuery("#input_" + inputFieldName).change(function() {
			var inputIsValid = isInputValid();
			if (inputIsValid) {
				input_button.prop('disabled', false);
			} else {
				input_button.prop('disabled', true);
			}
		});
	});
};