
//
// Each Bank uses its own CSV format to describe transactions. This bank-dependent transaction format (a raw transaction) has to be mapped to a bank-independent transactionFormat. This processed is called mapping. The process of mapping a raw transaction to a transaction is done by a mapper. Each bank CSV format will have its own mapper. All available mappers are accessable by the global 'mappers' instances.
// 
// '
// var transactions = rawTransactions.map(mappers.ing);
// '
// 
// When you want to create your own mapper, add a new '*SHORTBANKNAME*_mapper.js' file to the 'js/src/mapping/' directory and make sure to include it in the 'index.html' file.
// 
// After adding the file, the mapper has to be implemented. The mapper is a function that receives each individual raw transaction and it should preform two actions on each transaction:
// 1) First it should transform the raw transaction to the 'transactionFormat' as described below.
// 2) Secondly it should return a Transaction object using 'return new Transaction(transactionFormat);' from this transactionFormat.
// 
// The bank-independent transactionFormat looks like this:
// '
// var transactionFormat = 
// {
//  	 amount			AS number 		The amount of money transfered in this transaction (correctly signed),
//  	 date			AS datetime 	The date on which the transaction occurred,
//  	 myAccount		AS string		The account number (IBAN) of the user in this transaction,
//  	 otherAccount	AS string		The account number (IBAN) of the other party in this transaction,
//  	 otherName		AS string		The account name of the other party in this transaction,
//  	 information	AS string		Additional information about this transaction as a string,
//  }
// '
// 
// All mappers are located in the 'js/src/mapping/' directory. You can take a look at these as examples.
//

var mappers = {};